which

Function which 

pub fn which(tool: &JsString, check: Option<bool>) -> Promise
Returns path of a tool had the tool actually been invoked. Resolves via paths. If you check and the tool does not exist, it will throw.