find_all_versions

Function find_all_versions 

pub fn find_all_versions(tool: &JsString, arch: Option<&JsString>) -> Array
Finds the paths to all versions of a tool that are installed in the local tool cache.