Core functions for setting results, logging, registering secrets and exporting variables.
Structs
- Input
Options - Interface for getInput options
Enums
- Exit
Code - The code to exit an action
Functions
- add_
path - Prepends inputPath to the PATH (for this action and future actions).
- debug
- Writes debug message to user log.
- end_
group - End an output group.
- error
- Adds an error issue.
- export_
secret - Exports the variable and registers a secret which will get masked from logs.
- export_
variable - Sets env variable for this action and future actions in the job.
- get_
input - Gets the value of an input. The value is also trimmed.
- group
- Wrap an asynchronous function call in a group.
- info
- Writes info to log with console.log.
- issue
- issue_
command - set_
failed - Sets the action status to failed. When the action exits it will be with an exit code of 1.
- set_
output - Sets the value of an output.
- start_
group - Begin an output group.
- warning
- Adds an warning issue.